code stringlengths 2 1.05M | repo_name stringlengths 5 101 | path stringlengths 4 991 | language stringclasses 3
values | license stringclasses 5
values | size int64 2 1.05M |
|---|---|---|---|---|---|
# Uses FTP to pull the contents of a remote site
# into a local zip file
#
# Dependencies:
# NcFTPGet - part of NcFTP client from http://ncftp.com/download/
# 7-Zip command line - 7za.exe
param(
[string] $address,
[string] $userName,
[string] $password,
[string] $outputDir
)
# Create temp directory to download... | toddhgardner/dotfiles | powershell/script/Get-FtpBackup.ps1 | PowerShell | mit | 1,003 |
Function Set-ieStartPage {
<#
.Synopsis
Set IE Home page
.FUNCTIONALITY
Windows 8, Windows 8.1
#>
[CmdletBinding()]
Param ( $VerbosePreference = "Continue", $Url = "https://www.google.com" )
Begin{
$RegLocation = "HKCU:\Software\Microsoft\Internet Explorer\Main"
$Property1 = ... | y0ug/vmboxer | scripts/provisions/Custom-Win8.ps1 | PowerShell | mit | 5,359 |
param (
[string]$antBuildFile,
[string]$options,
[string]$targets,
[string]$publishJUnitResults,
[string]$testResultsFiles,
[string]$jdkVersion,
[string]$jdkArchitecture,
[string]$publishCodeCoverageResults,
[string]$codeCoverageTool,
[string]$summaryFileLocation,
[str... | azureautomation/vso-agent-tasks | Tasks/ANTPreview/ant.ps1 | PowerShell | mit | 3,502 |
Add-VisualStudioWorkload `
-PackageName 'visualstudio2022-workload-manageddesktopbuildtools' `
-Workload 'ManagedDesktopBuildTools' `
-VisualStudioYear '2022' `
-Preview $false `
-ApplicableProducts @('BuildTools') `
-IncludeRecommendedComponentsByDefault
| jberezanski/ChocolateyPackages | visualstudio2022-workload-manageddesktopbuildtools/tools/ChocolateyInstall.ps1 | PowerShell | mit | 283 |
[CmdletBinding()]
param(
[Parameter(Mandatory = $true)]
[String]
[ValidateLength(1, 20)]
$UserName,
[Parameter(Mandatory = $true)]
[String]
[ValidateLength(1, 20)]
$Password
)
$computer = [ADSI]"WinNT://$Env:COMPUTERNAME,Computer"
$users = $computer.Children |
? {$_.SchemaClassName -eq 'user'} |
... | Iristyle/puppetconf2014 | demo/Add-LocalUser.ps1 | PowerShell | mit | 608 |
<#
.EXAMPLE
Add a new host to the host file
#>
configuration RevertDSCServerHostFile
{
param
(
[string[]]
$NodeName = 'localhost'
)
Import-DSCResource -ModuleName xNetworking
$h = 0
Node $NodeName
{
Foreach ($Computer in $config.AllNodes.Where{$_.Role -matc... | aaronticehurst/DSC | ActiveDirectory/RevertDSCServerHostFile.ps1 | PowerShell | mit | 797 |
Function Get-NinjaCustomer {
<#
.SYNOPSIS
.DESCRIPTION
.EXAMPLE
#>
[CmdletBinding(DefaultParameterSetName='AllCustomers',
SupportsShouldProcess=$true,
PositionalBinding=$false,
HelpUri = 'https://githu... | MaxAnderson95/PoSHNinjaRMM-Management | sources/Public/Get-NinjaCustomer.ps1 | PowerShell | mit | 3,298 |
$packageName = 'ums'
$installerType = 'exe'
$silentArgs = '/S'
$url = 'http://sourceforge.net/projects/unimediaserver/files/Official%20Releases/Windows/UMS-6.0.0-Java7.exe/download'
$checksum = 'c6b1d1ef19f5498c5d030e1b99ab79d6bdc14cff'
$checksumType = 'sha1'
$validExitCodes = @(0)
Install-ChocolateyPackage -PackageN... | dtgm/chocolatey-packages | automatic/_output/ums/6.0.0/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 655 |
Function Get-TargetResource {
Param(
[Parameter(Mandatory=$True)]
[ValidateNotNullOrEmpty()]
[string]$MacAddress,
[Parameter(Mandatory=$False)]
[ValidateNotNullOrEmpty()]
[string]$Name,
[Parameter(Mandatory=$False)]
[ValidateNotNullOrEmpty()]
... | ConclusionMC/puppetlabs-dsc | lib/puppet_x/dsc_resources/cMisc/DSCResources/cMisc_ConfigureIPv4/cMisc_ConfigureIPv4.psm1 | PowerShell | apache-2.0 | 9,632 |
#
# Name
# Chocolatey.ps1
#
# Description
# This defines functions regarding 'Chocolatey'.
# ('Chocolatey' に関するファンクションを定義しています。)
#
# Depends
# .\Log.ps1
# .\File.ps1
# .\Execute.ps1
#
# Copyright (C) 2014 Keisuke Kukita
#
# Licensed under the Apache License, Version 2.0 (the "License");
# y... | kukita/PowerChef | PowerChef/Chocolatey.ps1 | PowerShell | apache-2.0 | 11,455 |
#!powershell
# <COPYRIGHT>
# <CODEGENMETA>
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.... | pyrotimux/server_playground | ansible/library/win_pc_xsqlserverinstall.ps1 | PowerShell | apache-2.0 | 15,625 |
function Add-VSWAFv2RuleGroupAllQueryArguments {
<#
.SYNOPSIS
Adds an AWS::WAFv2::RuleGroup.AllQueryArguments resource property to the template.
.DESCRIPTION
Adds an AWS::WAFv2::RuleGroup.AllQueryArguments resource property to the template.
.LINK
http://docs.aws.amazon.com/AW... | scrthq/Vaporshell | VaporShell/Public/Resource Property Types/Add-VSWAFv2RuleGroupAllQueryArguments.ps1 | PowerShell | apache-2.0 | 1,368 |
### functions
function Check-SoftwareInstalled ($displayName, $displayVersion) {
$registryPaths = @(
'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*',
'HKLM:\Software\WOW6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*'
)
return Get-ItemProperty $registryPaths -ErrorAction SilentlyCon... | ebugusey/chocolatey-coreteampackages | automatic/flashplayerplugin/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 995 |
$maxRows = 100000
$minRows = 40000
$daysCount = 4
$filesPerDay = Get-Random -minimum 1 -maximum 5
$prods = @(
@{ title="Halogen Headlights (2 Pack)"; cat="Lighting"; },
@{ title="Bugeye Headlights (2 Pack)"; cat="Lighting"; },
@{ title="Turn Signal Light Bulb"; cat="Lighting"; },
@{ title="Matte Finish Rim"; cat="... | jldeen/2016-Oct-L2 | Data/Module2-GainInsights/Setup/Archive/generateSampleDatapipe.ps1 | PowerShell | mit | 1,917 |
$packageName = 'locate32'
$urlArray = @('http://sourceforge.net/projects/locate32/files/olderversions/locate32-3.1.11.7100.zip/download', 'http://sourceforge.net/projects/locate32/files/olderversions/locate32_x64-3.1.11.7100.zip/download')
$url = $urlArray[0]
$checksum = '1d459b5b053f348f5ae0256cb1fe706ada31d507'
$chec... | dtgm/chocolatey-packages | automatic/_output/locate32/3.1.11.7100/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,146 |
echo "--- system details"
$Properties = 'Caption', 'CSName', 'Version', 'BuildType', 'OSArchitecture'
Get-CimInstance Win32_OperatingSystem | Select-Object $Properties | Format-Table -AutoSize
echo "ruby version:"
ruby -v
if (-not $?) { throw "Can't run Ruby. Is it installed?" }
echo "bundler version: "
bundle --vers... | MsysTechnologiesllc/chef | .expeditor/scripts/bk_win_prep.ps1 | PowerShell | apache-2.0 | 603 |
try {
$packageName = 'duplicatecleaner'
$packageUn = 'Duplicate Cleaner Free'
$fileType = 'exe'
$silentArgs = '/S'
$validExitCodes = @(0)
$osBitness = Get-ProcessorBits
if ($osBitness -eq 64) {
$unPath = 'HKLM:SOFTWARE\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall'
} else {
$unPath = 'HKLM:SOFTWAR... | dtgm/chocolatey-packages | automatic/_output/duplicatecleaner/3.2.6/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 692 |
$packageName = 'jrt'
$url = 'http://thisisudax.org/downloads/JRT.exe'
$checksum = '31c1f47bb72c6a1649970efb5f15e23f0ad6f57f'
$checksumType = 'sha1'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$installFile = Join-Path $toolsDir "$($packageName).exe"
try {
Get-ChocolateyWebFile -PackageName "... | dtgm/chocolatey-packages | automatic/_output/jrt/6.7.9/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 776 |
#########################################################################################
#
# Copyright (c) Microsoft Corporation. All rights reserved.
#
# Licensed under the MIT license.
#
# PSSwaggerUtility Module
#
#########################################################################################
Microsoft.Po... | AzureAutomationTeam/azure-powershell | src/StackAdmin/Azs.Commerce.Admin/Module/Azs.Commerce.Admin/PSSwaggerUtility/PSSwaggerUtility.psm1 | PowerShell | apache-2.0 | 56,705 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | pomortaz/azure-powershell | src/ResourceManager/Compute/Commands.Compute.Test/ScenarioTests/AddVhdTests.ps1 | PowerShell | apache-2.0 | 4,923 |
# Load the default configuration file in XML format
$Config = Get-ScriptConfig -Format 'XML'
# Access the configuration settings
Write-Verbose "String :" $Config.MyString
Write-Verbose "Integer Positive :" $Config.MyIntegerPositive
Write-Verbose "Integer Negative :" $Config.MyIntegerNegative
Write-Verbose "... | claudiospizzi/ScriptConfig | Modules/ScriptConfig/Tests/Integration/XmlConfigDemo.ps1 | PowerShell | mit | 766 |
#requires -modules BuildHelpers
#requires -modules @{ ModuleName = "Pester"; ModuleVersion = "4.4.0" }
Describe "ConvertTo-JiraFilter" -Tag 'Unit' {
BeforeAll {
Remove-Item -Path Env:\BH*
$projectRoot = (Resolve-Path "$PSScriptRoot/../..").Path
if ($projectRoot -like "*Release") {
... | AtlassianPS/JiraPS | Tests/Functions/ConvertTo-JiraFilter.Unit.Tests.ps1 | PowerShell | mit | 6,945 |
param(
[parameter(Mandatory=$TRUE)]
[String] $ResourceGroupName
)
$jobs = Get-AzureRmStreamAnalyticsJob -ResourceGroupName $ResourceGroupName
foreach ($job in $jobs)
{
Write-Host $job.JobName
$null = Stop-AzureRmStreamAnalyticsJob -Name $job.JobName -ResourceGroupName $ResourceGroupName
$null = Start-AzureR... | PlainConcepts/AdventureWorksSkiApp | deploy/Scripts/StartStreamJob.ps1 | PowerShell | mit | 436 |
<#
.EXAMPLE
This example shows how to set the Recovery Model
to "Full" for SQL database "AdventureWorks".
#>
Configuration Example
{
param
(
[Parameter(Mandatory = $true)]
[System.Management.Automation.PSCredential]
$SqlAdministratorCredential
)
Import-DscResource -Modu... | PowerShell/xSQLServer | Examples/Resources/SqlDatabaseRecoveryModel/1-SetDatabaseRecoveryModel.ps1 | PowerShell | mit | 1,763 |
Function CheckRepository($repositoryName){
svnadmin verify $repositoryName
If($LASTEXITCODE -eq 0){
Return $true
}
Return $false
}
Function CreateRepos($repositoryName){
svnadmin create $repositoryName
}
Function DeleteRepos($reposName){
Remove-Item -Path $reposName -Recurse -Force
}... | KobusGamification/Gamification | Gamification/SVNExtension.UnitTest/BuildTests/BuildSvnRepos.ps1 | PowerShell | mit | 1,681 |
function Get-EventBitsTransferComplete {
<#
.SYNOPSIS
Short description
.DESCRIPTION
Long description
.EXAMPLE
PS C:\> <example usage>
Explanation of what the example does
.INPUTS
Inputs (if any)
.OUTPUTS
Output (if any)
.NOTES
General ... | PSGumshoe/PSGumshoe | EventLog/Get-EventBitsTransferComplete.ps1 | PowerShell | mit | 4,298 |
#
# Copyright (c) Microsoft Corporation.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR AN... | OneGet/oneget | Test/DSCTests/tests/PackageManagement.Get.Tests.ps1 | PowerShell | mit | 9,740 |
<#
The MIT License (MIT)
Copyright (c) 2015 Objectivity Bespoke Software Specialists
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
t... | ObjectivityBSS/PSCI.teamcityMaintenance | Objectivity.TeamcityMaintenance/Private/Restore-TeamCityRestBackup.ps1 | PowerShell | mit | 4,221 |
# install.ps1
param($rootPath, $toolsPath, $package, $project)
$DTE.ItemOperations.Navigate("http://maartenba.github.io/MvcSiteMapProvider/getting-started.html", $DTE.vsNavigateOptions.vsNavigateOptionsNewWindow)
# SIG # Begin signature block
# MIIdiAYJKoZIhvcNAQcCoIIdeTCCHXUCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQ... | MicrosoftLearning/20486-DevelopingASPNETMVCWebApplications | Allfiles/20486C/Mod13/LabFiles/PhotoSharingApplication_13_end/packages/MvcSiteMapProvider.MVC5.4.6.22/tools/install.ps1 | PowerShell | mit | 10,835 |
$script:dscResourceCommonPath = Join-Path -Path $PSScriptRoot -ChildPath '..\..\Modules\DscResource.Common'
$script:dnsServerDscCommonPath = Join-Path -Path $PSScriptRoot -ChildPath '..\..\Modules\DnsServerDsc.Common'
Import-Module -Name $script:dscResourceCommonPath
Import-Module -Name $script:dnsServerDscCommonPath
... | PowerShell/xDnsServer | source/DSCResources/DSC_DnsServerForwarder/DSC_DnsServerForwarder.psm1 | PowerShell | mit | 4,764 |
$packageName = 'kodi'
$installerType = 'exe'
$silentArgs = '/S'
$url = 'http://mirrors.kodi.tv/releases/win32/kodi-17.0-Krypton.exe'
$checksum = 'd20c663f4655a38732646c1f1906c2bf79155ec05a3cb1ef638e604941bc3196'
$checksumType = 'sha256'
$validExitCodes = @(0)
Install-ChocolateyPackage -PackageName "$packageName" `
... | dtgm/chocolatey-packages | automatic/_output/kodi/17.0/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 635 |
#!powershell
# <COPYRIGHT>
# <CODEGENMETA>
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.... | pyrotimux/server_playground | ansible/library/win_ad_xaddomain.ps1 | PowerShell | apache-2.0 | 15,143 |
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed... | pshdo/Carbon | Test/Compress-Item.Tests.ps1 | PowerShell | apache-2.0 | 6,144 |
Import-Module au
Import-module "$PSScriptRoot\..\..\scripts\au_extensions.psm1"
function global:au_BeforeUpdate { Get-RemoteFiles -NoSuffix }
function global:au_AfterUpdate { Set-DescriptionFromReadme -SkipFirst 1 }
function global:au_GetLatest {
$downloadPageUrl = 'http://www.apachehaus.com/cgi-bin/download.plx... | octomike/chocolatey-coreteampackages | automatic/apache-httpd/update.ps1 | PowerShell | apache-2.0 | 1,437 |
Import-Module .\TestLibs\RDFELibs.psm1 -Force
$result = ""
$testResult = ""
$resultArr = @()
$isDeployed = DeployVMS -setupType $currentTestData.setupType -Distro $Distro -xmlConfig $xmlConfig
if ($isDeployed)
{
$vm1added = $false
foreach ($VMdata in $allVMData)
{
if ($VMdata.RoleName -imatch $currentTestData.set... | FreeBSDonHyper-V/azure-freebsd-automation | remote-scripts/NETWORK-LB-NO-PROBE-PORT-IPERF-NON-CONNETIVITY.ps1 | PowerShell | apache-2.0 | 7,983 |
function Get-TargetResource
{
[CmdletBinding()]
[OutputType([System.Collections.Hashtable])]
param
(
[parameter(Mandatory = $true)]
[System.String]
$Source,
[parameter(Mandatory = $true)]
[System.String]
$Destination,
[System.String... | cowofevil/puppetlabs-dsc | lib/puppet_x/dsc_resources/xRobocopy/DSCResources/MSFT_xRobocopy/MSFT_xRobocopy.psm1 | PowerShell | apache-2.0 | 4,924 |
<#
.SYNOPSIS
Tests if the current machine is a Nano server.
#>
function Test-IsNanoServer
{
if(Test-Command -Name Get-ComputerInfo)
{
$computerInfo = Get-ComputerInfo
if("Server" -eq $computerInfo.OsProductType `
-and "NanoServer" -eq $computerInfo.OsServerLevel)
{
... | puppetlabs/puppetlabs-dsc | lib/puppet_x/dsc_resources/ComputerManagementDsc/Modules/ComputerManagementDsc.ResourceHelper/ComputerManagementDsc.ResourceHelper.psm1 | PowerShell | apache-2.0 | 4,099 |
# Ensure we're on the right version of the tooling. If not, there's nothing for us to do here.
$toolingExists = [System.AppDomain]::CurrentDomain.GetAssemblies() | ?{ $_.GetType("Microsoft.VisualStudio.Web.Mvc.Scaffolding.ScaffolderProviders") }
if (!$toolingExists) { return }
# Todo: Scope the following to this ... | kissarat/dandy | packages/MvcScaffolding.1.0.6/tools/registerWithMvcTooling.ps1 | PowerShell | bsd-3-clause | 8,694 |
$machineName = "CHOZO"
# Get the ID and security principal of the current user account
$myIdentity=[System.Security.Principal.WindowsIdentity]::GetCurrent()
$myPrincipal=new-object System.Security.Principal.WindowsPrincipal($myIdentity)
# Check to see if we are currently running "as Administrator"
if (!$myPrincipa... | christophercaburog/dotfiles-windows | windows.ps1 | PowerShell | mit | 7,816 |
. .\BuildUtils\build_utils.ps1
$buildNumber = ($env:APPVEYOR_BUILD_NUMBER, "0" -ne $null)[0]
$version = Get-VersionFromTag
Update-AppveyorBuild -Version "$version.$buildNumber"
if ($env:APPVEYOR_REPO_BRANCH -ne "release") {
$version = "$version.$buildNumber"
}
Patch-Xml "YamlDotNetEditor\source.extensio... | aaubry/YamlDotNet.Editor | prebuild.ps1 | PowerShell | mit | 547 |
###
# ==++==
#
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by a... | kmosher/PowerShell | src/Modules/Shared/PackageManagement/PackageProviderFunctions.psm1 | PowerShell | mit | 10,268 |
$packageName = 'moneyguru'
$installerType = 'msi'
$silentArgs = '/qn /norestart'
$url = 'http://download.hardcoded.net/dupeguru_pe_win64_2.9.0.msi'
$checksum = 'c23bde3062cbc107fa67c55309c5c26cb3dfbb79'
$checksumType = 'sha1'
$validExitCodes = @(0)
Install-ChocolateyPackage -PackageName "$packageName" `
... | dtgm/chocolatey-packages | automatic/_output/moneyguru/2.9.0/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 620 |
$packageName = 'usblogview'
$url = 'http://www.nirsoft.net/utils/usblogview.zip'
$checksum = 'e97e1d0a841552bba8a7ab6bbffb3c134da5ef9b'
$checksumType = 'sha1'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$installFile = Join-Path $toolsDir "$($packageName).exe"
Install-ChocolateyZipPackage -Pa... | dtgm/chocolatey-packages | automatic/_output/usblogview/1.12/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 670 |
$packageName = 'folderchangesview'
$url = 'http://www.nirsoft.net/utils/folderchangesview.zip'
$checksum = '6ae0bf86d57e68e02ed35e780b7f0ca47dc802d3'
$checksumType = 'sha1'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$installFile = Join-Path $toolsDir "$($packageName).exe"
Install-Chocolatey... | dtgm/chocolatey-packages | automatic/_output/folderchangesview/1.71/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 684 |
<#
.SYNOPSIS
Basic end to end diagnostics extension.
#>
function Test-AzureServiceDiagnosticsExtensionBasic
{
Set-StrictMode -Version latest; $ErrorActionPreference = 'Stop'
# Setup
$location = Get-DefaultLocation
$svcName = Get-CloudServiceName
$storageName = getAssetName
$svcName = "onesdk52... | juvchan/azure-powershell | src/ServiceManagement/Common/Commands.ScenarioTest/Resources/DiagnosticsExtension/DiagnosticsExtensionTests.ps1 | PowerShell | apache-2.0 | 4,711 |
function New-HoneyHash {
<#
.SYNOPSIS
Inject artificial credentials into LSASS. Inspired by Mark Baggett's article:
https://isc.sans.edu/diary/Detecting+Mimikatz+Use+On+Your+Network/19311/
Author: Matthew Graeber (@mattifestation)
License: BSD 3-Clause
Required Dependencies: None
Optional Dependencies: None
.DESCRIP... | Yas3r/Empire | data/module_source/management/New-HoneyHash.ps1 | PowerShell | bsd-3-clause | 3,503 |
$script:DSCModuleName = 'xExchange'
$script:DSCResourceName = 'MSFT_xExchReceiveConnector'
$script:moduleRoot = Split-Path -Parent (Split-Path -Parent $PSScriptRoot)
Import-Module -Name (Join-Path -Path $script:moduleRoot -ChildPath (Join-Path -Path 'tests' -ChildPath (Join-Path -Path 'TestHelpers' -ChildPath 'xExchan... | mhendric/xExchange | tests/Unit/MSFT_xExchReceiveConnector.tests.ps1 | PowerShell | mit | 5,689 |
#Requires -Version 3.0
Param(
[string] [Parameter(Mandatory=$true)] $ResourceGroupLocation,
[string] $ResourceGroupName = 'SampleResourceGroup',
[switch] $UploadArtifacts,
[string] $StorageAccountName,
[string] $StorageContainerName = $ResourceGroupName.ToLowerInvariant() + '-stageartifacts',
[string] $T... | devkimchi/Sample-Resource-Group | src/AzureResourceGroup/Scripts/Deploy-AzureResourceGroup.ps1 | PowerShell | mit | 4,598 |
Configuration DevFileServer
{
Import-DscResource -Name xSmbShare -ModuleName xSmbShare
Import-DscResource -ModuleName PSDesiredStateConfiguration
#User Home directories
file Users
{
Ensure = 'Present'
Type = 'Directory'
DestinationPath = '... | grayzu/Examples | Configs/DSConNano/DevFileServer_Config.ps1 | PowerShell | mit | 2,778 |
# -----------------------------------------
# Deployment Mode
# -----------------------------------------
$DSP_IsDistributedEnvironment = "$false"
# ******************************************
# Application Configuration
# ******************************************
$DSP_PortalWebAppUrl = "http://dynamite.com/"
$DSP_P... | GSoft-SharePoint/Dynamite-Components | Source/GSoft.Dynamite.VanillaCrossSiteCMS.Scripts/Tokens.FRANCK-VM2013.ps1 | PowerShell | mit | 1,369 |
# Do While Loop
$NumberOfVms = 5
$vmCount = 0
# Will always run the first time!
Do
{
$vmName = “test_” + $vmCount
Write-Output "Creating VM: $vmName"
New-VM -Name $vmName -VM “base” -Datastore "NVMe_203" -LinkedClone -ReferenceSnapShot “base” -VMHost $vmhost | Out-Null
# Increase the count (Or yo... | jpsider/Invoke-Automation | Powercli/VMWorld2021/vmw21_Do-While.ps1 | PowerShell | mit | 520 |
<#
Version 3.0 BETA notes:
- The help is not finished for the module
- There are some examples of the new functionality, but there will be mroe
- More will be added/fixed before 3.0 is released
Version 3.1 (or later) features:
- Get-EffectiveAccess will allow additional groups, user claims, and device c... | PowerShellOrg/PowerShellAccessControl | PowerShellAccessControl.psm1 | PowerShell | mit | 212,261 |
#Fill in the values below and save to your content store.
#region Node Definition: Master
$Master = New-Node -Name 'Master' -NodeId '1883264f-9536-4466-a81c-77d8fbfec315' -Type 'DscTestMasterNode'
#region Target Config: DscDC
$DscDC = New-TargetConfig -Properties @{
ConfigName = 'DscDC'
ContentHost = $false
... | devopsjesus/dscpush | DSCPushSetup/DefinitionStore/NodeDefinitionTwoTargets.ps1 | PowerShell | mit | 1,963 |
$here = Split-Path -Parent $MyInvocation.MyCommand.Path
$sut = (Split-Path -Leaf $MyInvocation.MyCommand.Path).Replace(".Tests.", ".")
if (-not (Get-Module 'gitlab-api')) {
$Parent = Split-Path -Parent $here
Import-Module "${Parent}\gitlab-api.psm1"
}
Describe $sut {
$GitLabPrivateToken = $env:Gi... | UNT-CAS-ITS/GitLab-API | functions/Test-GitLabPrivateToken.Tests.ps1 | PowerShell | mit | 937 |
function Get-TargetResource
{
[CmdletBinding()]
[OutputType([System.Collections.Hashtable])]
param
(
[parameter(Mandatory = $true)] [System.String] $UserProfileServiceAppName,
[parameter(Mandatory = $false)] [ValidateSet("Present","Absent")] [System.String] $Ensure = "Present",
... | camiloborges/xSharePoint | Modules/SharePointDsc/DSCResources/MSFT_SPUserProfileSyncService/MSFT_SPUserProfileSyncService.psm1 | PowerShell | mit | 7,503 |
$packageName = 'firefox-nightly'
$installerType = 'exe'
$silentArgs = '/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-'
$url = 'https://archive.mozilla.org/pub/firefox/nightly/latest-mozilla-central/firefox-54.0a1.en-US.win32.installer.exe'
$checksum = 'dedb63051add3c128808dffff2e9f2e4ead5a981b11f051d12e1dd8527ed93be'
$... | dtgm/chocolatey-packages | automatic/_output/firefox-nightly/54.0.1.2017022015/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,134 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | mayurid/azure-powershell | src/ResourceManager/Dns/Commands.Dns.Test/ScenarioTests/Common.ps1 | PowerShell | apache-2.0 | 1,570 |
$packageName = 'dolphin'
$url = 'http://dl.dolphin-emu.org/builds/dolphin-master-4.0-8977-x64.7z'
$checksum = 'e323ad97af718d120fd13e829195ade374b932e9'
$checksumType = 'sha1'
$url64 = $url
$checksum64 = $checksum
$checksumType64 = $checksumType
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
In... | dtgm/chocolatey-packages | automatic/_output/dolphin/4.0.8977/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 761 |
#
# Module manifest for module 'Microsoft.Azure.Commands.Cdn'
#
# Generated by: Microsoft Corporation
#
# Generated on: 2/24/2016
#
@{
# Version number of this module.
ModuleVersion = '2.1.0'
# ID used to uniquely identify this module
GUID = '52594002-DB89-46DF-928D-2755DAD840E8'
# Aut... | arcadiahlyy/azure-powershell | src/ResourceManager/Cdn/AzureRM.Cdn.psd1 | PowerShell | apache-2.0 | 3,286 |
$packageName = 'dolphin'
$url = 'http://dl.dolphin-emu.org/builds/dolphin-master-5.0-2538-x64.7z'
$checksum = 'e573ff707e3e2c890c8597d23341a79c7951a0d8dc234a6562fd9a831cde584c'
$checksumType = 'sha256'
$url64 = $url
$checksum64 = $checksum
$checksumType64 = $checksumType
$toolsDir = "$(Split-Path -parent $MyInvocation... | dtgm/chocolatey-packages | automatic/_output/dolphin/5.0.2538/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 790 |
$UcsConfiguration = @{}
<########################################################################################
Connection Details
Username = [string] Username for connecting to UCS domains
Domain = [string[]] List of UCS domains to connect to (Hostname or IP)
#>
$UcsConfiguration.Connection... | FooBartn/Ucs-Puptr | Ucs-Puptr/Templates/Configuration-Template.ps1 | PowerShell | apache-2.0 | 15,606 |
# The following options are available through profiles:
# (JSON can be single/double-quoted and contain comments.)
# {
# "profiles": [
# {
# "profile1": {
# "TextSmoothingMode": "HighQuality", // Valid values: "HighSpeed", "HighQuality"
# "VectorSmoothingMode": "H... | bytescout/ByteScout-SDK-SourceCode | PDF.co Web API/PDF To JPG/PowerShell/Advanced JPEG Conversion Options/ConvertPdfToJpegFromUrl.ps1 | PowerShell | apache-2.0 | 3,289 |
function Import-WhiskeyTask
{
[Whiskey.Task("LoadTask")]
[CmdletBinding()]
param(
[Parameter(Mandatory=$true)]
[Whiskey.Context]
$TaskContext,
[Parameter(Mandatory=$true)]
[hashtable]
$TaskParameter
)
Set-StrictMode -Version 'Late... | pshdo/LibGit2.PowerShell | .whiskey/Tasks/Import-WhiskeyTask.ps1 | PowerShell | apache-2.0 | 2,108 |
<#
.SYNOPSIS
Determines whether the assembly name is fully qualified
.DESCRIPTION
Determines whether the assembly name is fully qualified. An assembly name is fully qualified if
it contains all the following parts:
* Name
* Version
* Culture
* PublicKeyToken
* ProcessorArchitecture
Note t... | LTruijens/powershell-gac | PowerShellGac/Gac/Test-AssemblyNameFullyQualified.ps1 | PowerShell | bsd-2-clause | 1,463 |
function InstallMissingHeaders () {
# Visual Studio 2008 is missing stdint.h, but you can just download one
# from the web.
# http://stackoverflow.com/questions/126279/c99-stdint-h-header-and-ms-visual-studio
$webclient = New-Object System.Net.WebClient
$include_dirs = @("C:\Program Files\Microsoft... | HexDecimal/multibuild | ci/appveyor/missing-headers.ps1 | PowerShell | bsd-2-clause | 1,884 |
function Copy-DbaSpConfigure {
<#
.SYNOPSIS
Copy-DbaSpConfigure migrates configuration values from one SQL Server to another.
.DESCRIPTION
By default, all configuration values are copied. The -ConfigName parameter is auto-populated for command-line completion and can be used to copy only sp... | wsmelton/dbatools | functions/Copy-DbaSpConfigure.ps1 | PowerShell | mit | 8,668 |
function Backup-DbaDbCertificate {
<#
.SYNOPSIS
Exports database certificates from SQL Server using SMO.
.DESCRIPTION
Exports database certificates from SQL Server using SMO and outputs the .cer and .pvk files.
.PARAMETER SqlInstance
The target SQL Server instance or instances.... | alevyinroc/dbatools | functions/Backup-DbaDbCertificate.ps1 | PowerShell | mit | 11,848 |
$packageName = 'sqlitebrowser'
$installerType = 'exe'
$silentArgs = '/S'
$url = 'https://github.com/sqlitebrowser/sqlitebrowser/releases/download/v3.6.0/sqlitebrowser-3.6.0v3-win32.exe'
$checksum = '70fb120aca2fd83781347454ce5e4df1'
$checksumType = 'md5'
$url64 = 'https://github.com/sqlitebrowser/sqlitebrowser/releases... | dtgm/chocolatey-packages | automatic/_output/sqlitebrowser/3.6.0.3/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,000 |
$packageName = 'winrar'
$version_x64 = "WinRAR 5.11 (64-bit)"
$version_x86 = "WinRAR 5.11 (32-bit)"
$uninstallRegistryPath = "HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\WinRAR archiver"
$installerType = 'EXE'
$url = 'http://www.rarlab.com/rar/winrar-x64-511.exe'
$silentArgs = '/S'
$validExitCodes = @(0)... | dtgm/chocolatey-packages | automatic/_output/winrar/5.11/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 20,498 |
$packageName = 'vcredist2015'
$installerType = 'exe'
$url = 'https://download.microsoft.com/download/C/E/5/CE514EAE-78A8-4381-86E8-29108D78DBD4/VC_redist.x86.exe'
$checksum = '17b381d3adb22f00e4ab47cbd91ce0a5b1ccbc70'
$checksumType = 'sha1'
$url64 = 'https://download.microsoft.com/download/C/E/5/CE514EAE-78A8-4381-86E... | lennartb-/chocolatey-coreteampackages | manual/vcredist2015/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 1,967 |
# Utility functions used by verious Orleans Deployment scripts.
#requires -version 2.0
# Function to determine if the current session has administrator privledges.
Function IsUserAdministrator
{
$user = [System.Security.Principal.WindowsIdentity]::GetCurrent()
$userPrincipal = new-object System.Securit... | yaronthurm/orleans | misc/scripts/RemoteDeployment/UtilityFunctions.ps1 | PowerShell | mit | 15,624 |
[CmdletBinding()]
param()
# Arrange.
. $PSScriptRoot\..\..\lib\Initialize-Test.ps1
. $PSScriptRoot\..\..\..\Tasks\PublishSymbols\IndexHelpers\DbghelpFunctions.ps1
$env:AGENT_HOMEDIRECTORY = 'SomeDrive:\AgentHome'
Register-Mock Assert-VstsPath { "$env:AGENT_HOMEDIRECTORY\Agent\Worker\Tools\Symstore\dbghelp.dll" }
Regis... | cwoolum/vso-agent-tasks | Tests/L0/PublishSymbols/Add-DbghelpLibrary.LoadsIfNotLoaded.ps1 | PowerShell | mit | 902 |
param (
[ValidateScript({Test-Path -PathType Leaf -Path $_})]
[Parameter(Mandatory=$true, HelpMessage='The location of the storage config.')]
$storageConfig,
$roleName,
$rolePlaceHolder,
$roleUrl,
[hashtable]$roleProperties,
[switch]$usePlaceholders=$false
)
$scriptPath =... | TridionPractice/autoInstall | Merge-RoleToConfigRepository.ps1 | PowerShell | mit | 1,789 |
## This command is used to execute an escript using the release ERTS
escript @args
| bitwalker/distillery | priv/libexec/commands/win/escript.ps1 | PowerShell | mit | 84 |
function Start-RBResultDashboard {
[CmdletBinding()]
param (
[Parameter(Mandatory)]
[PSCustomObject] $ControlResult,
[Parameter(Mandatory)]
[PSCustomObject] $VariationResult,
[Parameter(Mandatory)]
[PSCustomObject] $Difference,
[Parameter()]
[s... | Windos/powershell-depot | Modules/RunBucket/Private/Start-RBResultDashboard.ps1 | PowerShell | mit | 5,495 |
cls
# Pops out an input box for desired string to be found.
[System.Reflection.Assembly]::LoadWithPartialName('Microsoft.VisualBasic') | Out-Null
[string]$SearchTerm = [Microsoft.VisualBasic.Interaction]::InputBox("Enter the desired search string.
(Beware of trailing spaces!)", "Log Search", "")
# First is text of ... | CincyPowerShell/CincyPowerShell.github.io | presentations/2017-02/code/Invoke-LogSearch.ps1 | PowerShell | mit | 2,872 |
<#
.SYNOPSIS
Gets the contents of one or more work items.
.PARAMETER Project
${HelpParam_Project}
.PARAMETER Collection
${HelpParam_Collection}
.INPUTS
Microsoft.TeamFoundation.WorkItemTracking.Client.Project
System.String
#>
Function Get-TfsWorkItem
{
[CmdletBinding(DefaultParameterSetName=... | egomesbrandao/tfscmdlets | src/PS/WorkItem/Get-TfsWorkItem.ps1 | PowerShell | mit | 6,513 |
function Get-ContentPaginated {
[CmdletBinding()]
param(
[Parameter(Position = 0, Mandatory)]
$InputObject
)
if ($host.Name -eq 'ConsoleHost') {
try {
Get-Content $InputObject | Out-Host -Paging
}
catch {
}
}
else {
Write-Warn... | gravejester/Communary.ToolBox | Functions/Misc/Get-ContentPaginated.ps1 | PowerShell | mit | 429 |
Function ConvertTo-InsecureString {
<#
.SYNOPSIS
Returns string value from SecureString input
.DESCRIPTION
Gets the decoded string value of an encoded SecureString
.PARAMETER SecureString
The SecureString to decode
.EXAMPLE
ConvertTo-InsecureString $SecureStringValue
#>
[CmdLetBinding()]
[OutputType('Sys... | pspete/PoShPACLI | PoShPACLI/Private/ConvertTo-InsecureString.ps1 | PowerShell | mit | 703 |
New-ItemProperty -Path HKLM:Software\Microsoft\Windows\CurrentVersion\Policies\System -Name EnableLUA -PropertyType DWord -Value 0 -Force | Out-Null
Write-Host "User Access Control (UAC) has been disabled." -ForegroundColor Green | sparerd/vagrant | SharedScripts/Windows/SystemConfig/disable_uac.ps1 | PowerShell | mit | 229 |
<#
.SYNOPSIS
Generates a JSON object representing an Azure Pipelines Job Matrix.
See https://docs.microsoft.com/en-us/azure/devops/pipelines/process/phases?view=azure-devops&tabs=yaml#parallelexec
.EXAMPLE
./eng/common/scripts/Create-JobMatrix $context
#>
[CmdletBinding()]
param (
[Par... | tg-msft/azure-sdk-tools | eng/common/scripts/job-matrix/Create-JobMatrix.ps1 | PowerShell | mit | 1,209 |
function Get-JiraIssueAttachment {
# .ExternalHelp ..\JiraPS-help.xml
[CmdletBinding()]
param(
[Parameter( Mandatory, ValueFromPipeline, ValueFromPipelineByPropertyName )]
[ValidateNotNullOrEmpty()]
[ValidateScript(
{
if (("JiraPS.Issue" -notin $_.PSObject... | AtlassianPS/JiraPS | JiraPS/Public/Get-JiraIssueAttachment.ps1 | PowerShell | mit | 2,628 |
<#
.SYNOPSIS
Install a transport agent on an Exchange Server 2010
Thomas Stensitzki
THIS CODE IS MADE AVAILABLE AS IS, WITHOUT WARRANTY OF ANY KIND. THE ENTIRE
RISK OF THE USE OR THE RESULTS FROM THE USE OF THIS CODE REMAINS WITH THE USER.
Version 1.0, 2013
Please send i... | Apoc70/TransportAgent2010 | Add-TransportAgent.ps1 | PowerShell | mit | 2,580 |
$modulePath = Join-Path -Path (Split-Path -Path (Split-Path -Path $PSScriptRoot -Parent) -Parent) -ChildPath 'Modules'
Import-Module -Name (Join-Path -Path $modulePath -ChildPath 'DscResource.Common')
# Import Localization Strings
$script:localizedData = Get-LocalizedData -DefaultUICulture 'en-US'
<#
.SYNOPSIS
... | PowerShell/xNetworking | source/Modules/NetworkingDsc.Common/NetworkingDsc.Common.psm1 | PowerShell | mit | 18,173 |
[cmdletbinding()]
param(
[parameter(mandatory)]
$Options
)
begin {
Write-Debug -Message 'Chef provisioner: beginning'
}
process {
try {
Write-Verbose -Message 'Configuring Chef client...'
$provOptions = ConvertFrom-Json -InputObject $Options.Provisioners
$chefOptions = ($provOp... | devblackops/POSHOrigin_vSphere | POSHOrigin_vSphere/DSCResources/POSHOrigin_vSphere_VM/Provisioners/Chef/Provision.ps1 | PowerShell | apache-2.0 | 17,153 |
function Enable-DbaTraceFlag {
<#
.SYNOPSIS
Enable Global Trace Flag(s)
.DESCRIPTION
The function will set one or multiple trace flags on the SQL Server instance(s) listed.
These are not persisted after a restart, use Set-DbaStartupParameter to set them to persist after restarts.
... | wsmelton/dbatools | functions/Enable-DbaTraceFlag.ps1 | PowerShell | mit | 4,092 |
[CmdletBinding()]
[OutputType([string])]
param
(
[Parameter(Mandatory = $true, Position = 0, ValueFromPipeline = $true)]
[ValidatePattern('^(?<b>\{)?[A-F0-9]{8}-([A-F0-9]{4}-){3}[A-F0-9]{12}(?(b)\})$')]
[string[]] $Guid
)
begin
{
$Translation = 7,6,5,4,3,2,1,0,11,10,9,8,15,14,13,12,17,16,19,18,21,20,23... | jkorell/psmsi | tools/ConvertTo-SquishedGuid.ps1 | PowerShell | mit | 987 |
# https://msdn.microsoft.com/en-us/virtualization/windowscontainers/quick_start/quick_start_windows_10
Set-ExecutionPolicy Bypass -scope Process
New-Item -Type Directory -Path "$($env:ProgramFiles)\docker"
$wc = New-Object net.webclient
$wc.Downloadfile("https://get.docker.com/builds/Windows/x86_64/docker-17.03.0-ce.z... | sealsystems/pi-cloud | prepare-hardware/up-win10/usb/scripts/install-docker.ps1 | PowerShell | mit | 733 |
function Get-ADSIOrganizationalUnit
{
<#
.SYNOPSIS
This function will query Active Directory for Organization Unit Objects
.DESCRIPTION
This function will query Active Directory for Organization Unit Objects
.PARAMETER Name
Specify the Name of the OU
.PARAMETER DistinguishedName
Specify the Distingu... | lazywinadmin/AdsiPS | src/public/Get-ADSIOrganizationalUnit.ps1 | PowerShell | mit | 5,820 |
$packageName = 'sandboxie.beta'
$installerType = 'EXE'
$url = 'http://www.sandboxie.com/SandboxieInstall32-407-05.exe'
$url64 = 'http://www.sandboxie.com/SandboxieInstall64-407-05.exe'
$silentArgs = '/install /S /D=C:\Program Files\Sandboxie'
Install-ChocolateyPackage "$packageName" "$installerType" "$silentArgs" "$... | dtgm/chocolatey-packages | automatic/_output/sandboxie.beta/4.07.05/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 335 |
#
# Module manifest for module 'Microsoft.Azure.Commands.Network'
#
# Generated by: Microsoft Corporation
#
# Generated on: 9/19/2015
#
@{
# Version number of this module.
ModuleVersion = '1.0.12'
# ID used to uniquely identify this module
GUID = 'eb75c732-e274-4a20-b502-e9958e63484a'
# Author of this module
Auth... | hovsepm/azure-powershell | src/ResourceManager/Network/AzureRM.Network.psd1 | PowerShell | apache-2.0 | 3,158 |
$lapackPathFile = Join-Path $PSScriptRoot ..\.stack-work\lapack-path.txt
if (Test-Path $lapackPathFile) {
$lapackPath = (Get-Content -Raw $lapackPathFile).Trim()
}
else {
pushd $PSScriptRoot
stack exec -- sh get-lapack-path.sh | Add-Content $lapackPathFile
popd
}
if (-not ($env:PATH -match [Regex]::Escape($la... | rcook/mlutil | mlutil/script/env.ps1 | PowerShell | mit | 380 |
<#
.SYNOPSIS
Waits for changes made by DevCon.exe to complete before continuing.
.DESCRIPTION
Waits for the DevCon.exe process to exit and then checks whether Get-NetAdapter completes successfully.
Get-NetAdapter will throw "Illegal operation attempted on a registry key that has been ma... | PlagueHO/LoopbackAdapter | source/Private/Wait-ForDevconUpdate.ps1 | PowerShell | mit | 1,561 |
function Get-SysmonRegistryKey {
<#
.SYNOPSIS
Get Sysmon Registry Key events (Event Id 12) from a local or remote host.
.DESCRIPTION
Get Sysmon Registry Key events from a local or remote host. Events can be filtered by fields.
.INPUTS
System.IO.FileInfo
.OUTPUTS
Sysmo... | PSGumshoe/PSGumshoe | EventLog/Get-SysmonRegistryKey.ps1 | PowerShell | mit | 4,024 |
$DBValueSqlConnection = $null
function CheckSqlCount()
{
if ($global:ConfigXml.servermonitor.SelectNodes("sqlcount").count -ne 1)
{
ShowInfo "sqlcount node not found"
return
}
CheckDatabase
}
function CheckScalarCount($name,$expectedNumber,$comparer,$sql)
{
try
{... | hahndorf/ServerMonitor | smpSqlCount.ps1 | PowerShell | mit | 3,050 |
[String]$global:saveLastConfigFile = $NULL
[String]$global:saveLastFilePath = $NULL
$validProductIds = @("O365ProPlusRetail","O365BusinessRetail","VisioProRetail","ProjectProRetail", "SPDRetail")
$enum = "
using System;
namespace Microsoft.Office
{
[FlagsAttribute]
public enum Products
{
Un... | KurtDeGreeff/Office-IT-Pro-Deployment-Scripts | Edit-OfficeConfigurationFile/Edit-OfficeConfigurationFile.ps1 | PowerShell | mit | 77,885 |
cat .\codes.txt | foreach {
$code, $name, $origin, $arg, $desc = $_ -split "`t";
if ($desc) { $desc = " $desc" }
if (!$origin) { $origin = "Unknown" }
"# $code $arg`n#$desc [$origin]`n$code = '$name';`n" } | alejandro5042/Run-IrcBot | dev/code-parser.ps1 | PowerShell | mit | 221 |
Describe $($PSCommandPath -Replace '.Tests.ps1') {
BeforeAll {
#Get Current Directory
$Here = Split-Path -Parent $PSCommandPath
#Assume ModuleName from Repository Root folder
$ModuleName = Split-Path (Split-Path $Here -Parent) -Leaf
#Resolve Path to Module Directory
... | pspete/psPAS | Tests/Set-PASGroup.Tests.ps1 | PowerShell | mit | 3,059 |
###########################################################################
#
# NAME: New-RDCManFile.ps1
#
# AUTHOR: Markus Lassfolk
# EMAIL: markus.lassfolk@truesec.se
#
# Original AUTHOR: Jan Egil Ring
# EMAIL: jer@powershell.no
#
# COMMENT: Script to create an XML-file for use with Microsoft Remote Desktop... | Nestil/Generic-Scripts-Public | Nes-serverdeployment/Default deployment/New-RDCManFile.ps1 | PowerShell | mit | 6,694 |
<#
.SYNOPSIS
Clears the output of one or more previous PrtgAPI builds.
.DESCRIPTION
The Clear-PrtgBuild clears the output of previous builds of PrtgAPI. By default, Clear-PrtgBuild will attempt to use the appropriate build tool (msbuild or dotnet.exe) to clear the previous build. If If -Full is specified, Clear-PrtgBu... | lordmilko/PrtgAPI | build/PrtgAPI.Build/Functions/Clear-PrtgBuild.ps1 | PowerShell | mit | 3,530 |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.